@@ -6,34 +6,39 @@ USE_TZ = True
 SITE_ID = 1
 
 TINYLINK_LENGTH = 5
-TINYLINK_PREFIX = '/'
+TINYLINK_CHECK_INTERVAL = 10
+TINYLINK_CHECK_PERIOD = 300
+
+PASSWORD_HASHERS = (
+    'django.contrib.auth.hashers.MD5PasswordHasher',
+)
 
 CURRENT_DIR = os.path.dirname(__file__)
 
-DATABASES={
+DATABASES = {
     "default": {
         "ENGINE": "django.db.backends.sqlite3",
         "NAME": ":memory:",
     }
 }
 
-ROOT_URLCONF='tinylinks.tests.urls'
+ROOT_URLCONF = 'tinylinks.tests.urls'
 
-STATIC_URL='/static/'
+STATIC_URL = '/static/'
 
-STATIC_ROOT=os.path.join(CURRENT_DIR, '../../static/')
+STATIC_ROOT = os.path.join(CURRENT_DIR, '../../static/')
 
-STATICFILES_DIRS=(
+STATICFILES_DIRS = (
     os.path.join(CURRENT_DIR, 'test_static'),
 )
 
-TEMPLATE_DIRS=(
-    os.path.join(CURRENT_DIR,'../templates'),
+TEMPLATE_DIRS = (
+    os.path.join(CURRENT_DIR, '../templates'),
 )
 
-JASMINE_TEST_DIRECTORY=os.path.join(CURRENT_DIR, 'jasmine_tests')
+JASMINE_TEST_DIRECTORY = os.path.join(CURRENT_DIR, 'jasmine_tests')
 
-COVERAGE_REPORT_HTML_OUTPUT_DIR=os.path.join(
+COVERAGE_REPORT_HTML_OUTPUT_DIR = os.path.join(
     CURRENT_DIR, 'coverage')
 
 COVERAGE_MODULE_EXCLUDES = [
@@ -52,6 +57,7 @@ EXTERNAL_APPS = [
     'django.contrib.sitemaps',
     'django.contrib.sites',
     'django_jasmine',
+    'django_libs',
 ]
 
 INTERNAL_APPS = [
